
# Quickstart

## Installation

```bash
pip install xplt
```

## Gallery

Click on the plots below to show the respective section in the [User guide](usage):

|Floor plan from survey | Twiss parameters | Phasespace distributions|
|:-:|:-:|:-:|
|[![](gallery/floorplot.png)](examples/line.ipynb#survey) | [![](gallery/twissplot.png)](examples/twiss) | [![](gallery/phasespaceplot.png)](examples/phasespace) |

| Beam positions | Spill time structure | Spill quality |
|:-:|:-:|:-:|
| [![](gallery/bpm.png)](examples/timestructure.ipynb#binned-time-series) | [![](gallery/spill.png)](examples/timestructure) | [![](gallery/spillquality.png)](examples/timestructure.ipynb#spill-quality) |
